#!/usr/bin/env node
"use strict";
/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2021-2022. All rights reserved.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const process_1 = __importDefault(require("process"));
const semver_1 = require("semver");
const exit_js_1 = require("../src/base/boot/hooks/exit.js");
const util_js_1 = require("../src/cli/wrapper/util.js");
const path_1 = __importDefault(require("path"));
const base_log_js_1 = __importDefault(require("../src/base/log/base-log.js"));
// 初始化命令行和日志等级
const cli_js_1 = require("../src/cli/main/cli.js");
// 顺序不要改变
const hvigorProjectHome = (0, util_js_1.getHvigorProjectHome)();
const cliOptions = (0, cli_js_1.parseCommand)();
const LOWEST_NODE_VERSION = 'v14.19.1';
// 优先检查node 的版本 要放在 parseCommand() 后面，不然日志 不会截断处理。
if ((0, semver_1.lt)(process_1.default.version, LOWEST_NODE_VERSION)) {
    base_log_js_1.default.error(`current node version: ${process_1.default.version}, node version cannot be lower than ${LOWEST_NODE_VERSION}`);
    (0, exit_js_1.exit)(-1);
}
// 初始化nodePath同时后台启动一个daemon
const daemon_process_factory_js_1 = require("../src/base/daemon/process/daemon-process-factory.js");
const prepare_node_path_js_1 = require("../src/cli/wrapper/prepare-node-path.js");
const const_1 = require("../src/common/const/const");
(0, prepare_node_path_js_1.initNodePath)(path_1.default.join(hvigorProjectHome, const_1.WORK_SPACE));
if (needStartDaemon(cliOptions)) {
    daemon_process_factory_js_1.defaultDaemonServerFactory.createDaemonFork();
}
(0, cli_js_1.startHvigorBuild)(cliOptions);
// 如果不是stop 和 status命令  且是daemon模式
function needStartDaemon(cliArgv) {
    return !cliArgv.stopDaemon && // --stop-daemon
        !cliArgv.stopDaemonAll && // --stop-daemon-all
        !cliArgv.statusDaemon && // --status
        cliArgv.daemon !== false; // daemon模式或未设置默认为daemon
}
//# sourceMappingURL=hvigor.js.map